@@ -1,14 +1,14 @@
 # URL extractor
 # Copyright 2004, Paul McGuire
-from pyparsing import makeHTMLTags, pyparsing_common as ppc
+from pyparsing import make_html_tags, pyparsing_common as ppc
 from urllib.request import urlopen
 import pprint
 
-linkOpenTag, linkCloseTag = makeHTMLTags("a")
+linkOpenTag, linkCloseTag = make_html_tags("a")
 
 linkBody = linkOpenTag.tag_body
-linkBody.setParseAction(ppc.stripHTMLTags)
-linkBody.addParseAction(lambda toks: " ".join(toks[0].strip().split()))
+linkBody.set_parse_action(ppc.strip_html_tags)
+linkBody.add_parse_action(lambda toks: " ".join(toks[0].strip().split()))
 
 link = linkOpenTag + linkBody("body") + linkCloseTag.suppress()
 
@@ -16,12 +16,12 @@ link = linkOpenTag + linkBody("body") + linkCloseTag.suppress()
 with urlopen("https://www.cnn.com/") as serverListPage:
     htmlText = serverListPage.read().decode("UTF-8")
 
-# scanString is a generator that loops through the input htmlText, and for each
+# scan_string is a generator that loops through the input htmlText, and for each
 # match yields the tokens and start and end locations (for this application, we are
 # not interested in the start and end values).
-for toks, strt, end in link.scanString(htmlText):
-    print(toks.asList())
+for toks, strt, end in link.scan_string(htmlText):
+    print(toks.as_list())
 
 # Create dictionary from list comprehension, assembled from each pair of tokens returned
 # from a matched URL.
-pprint.pprint({toks.body: toks.href for toks, strt, end in link.scanString(htmlText)})
+pprint.pprint({toks.body: toks.href for toks, strt, end in link.scan_string(htmlText)})
