@@ -115,8 +115,8 @@ class TestRailroadDiagrams(unittest.TestCase):
                 ), f"expected {expected_rr_len}, got {len(railroad)}"
 
     def test_nested_forward_with_inner_and_outer_names(self):
-        outer = pp.Forward().setName("outer")
-        inner = pp.Word(pp.alphas)[...].setName("inner")
+        outer = pp.Forward().set_name("outer")
+        inner = pp.Word(pp.alphas)[...].set_name("inner")
         outer <<= inner
 
         railroad = self.generate_railroad(outer, "inner_outer_names")
@@ -128,7 +128,7 @@ class TestRailroadDiagrams(unittest.TestCase):
 
     def test_nested_forward_with_inner_name_only(self):
         outer = pp.Forward()
-        inner = pp.Word(pp.alphas)[...].setName("inner")
+        inner = pp.Word(pp.alphas)[...].set_name("inner")
         outer <<= inner
 
         railroad = self.generate_railroad(outer, "inner_only")
@@ -144,7 +144,7 @@ class TestRailroadDiagrams(unittest.TestCase):
                 pp.Word(pp.alphas),
                 pp.pyparsing_common.uuid,
             ]
-        ).setName("int-word-uuid in any order")
+        ).set_name("int-word-uuid in any order")
         railroad = self.generate_railroad(grammar, "each_expression")
         assert len(railroad) == 2
         railroad = self.generate_railroad(
@@ -159,7 +159,7 @@ class TestRailroadDiagrams(unittest.TestCase):
         assert railroad[0].name is not None
 
     def test_none_name2(self):
-        grammar = pp.Or(["foo", "bar"]) + pp.Word(pp.nums).setName("integer")
+        grammar = pp.Or(["foo", "bar"]) + pp.Word(pp.nums).set_name("integer")
         railroad = to_railroad(grammar)
         assert len(railroad) == 2
         assert railroad[0].name is not None
